==> mythplugins_0.18.1.orig.tar.gz: mythplugins-0.18.1/mythbrowser/i18n/mythbrowser_sv.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>Bookmarks</name>
    <message>
        <source>MythBrowser: Select group or single site to view</source>
        <translation>MythBrowser: Välj grupp eller enstaka sida att se</translation>
    </message>
</context>
<context>
    <name>BookmarksConfig</name>
    <message>
        <source>MythBrowser Bookmarks Settings</source>
        <translation>MythBrowser bokmärkesinställningar</translation>
    </message>
    <message>
        <source>Press the &apos;New Bookmark&apos; button to add a new site/group.
Pressing SPACE/Enter on a selected entry removes it from the listview.</source>
        <translation>Tryck på knappen &apos;Nytt bokmärke&apos; för att lägga till en ny sida/grupp.
Ett tryck på Mellanslag/Enter på en markerad post tar bort den från listvisaren.</translation>
    </message>
    <message>
        <source>Zoom [%]:</source>
        <translation>Zoom [%]:</translation>
    </message>
    <message>
        <source>Browser:</source>
        <translation>Webbläsare:</translation>
    </message>
    <message>
        <source>Hide Scrollbars</source>
        <translation>Dölj rullningslister</translation>
    </message>
    <message>
        <source>Scroll Page</source>
        <translation>Rulla sida</translation>
    </message>
    <message>
        <source>Scroll Speed:</source>
        <translation>Rullningshastighet:</translation>
    </message>
    <message>
        <source>&amp;New Bookmark</source>
        <translation>&amp;Nytt bokmärke</translation>
    </message>
    <message>
        <source>Add a new Website</source>
        <translation>Lägg till en ny webbsida</translation>
    </message>
    <message>
        <source>&amp;Finish</source>
        <translation>&amp;Avsluta</translation>
    </message>
</context>
<context>
    <name>PopupBox</name>
    <message>
        <source>Add New Website</source>
        <translation>Lägg till ny webbsida</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Grupp:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Beskrivning:</translation>
    </message>
    <message>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <source>&amp;Ok</source>
        <translation>&amp;Ok</translation>
    </message>
</context>
<context>
    <name>TabView</name>
    <message>
        <source>MythBrowser Menu</source>
        <translation>MythBrowser-meny</translation>
    </message>
    <message>
        <source>         Back         </source>
        <translation>         Bakåt        </translation>
    </message>
    <message>
        <source>       Next Tab       </source>
        <translation>      Nästa tabb      </translation>
    </message>
    <message>
        <source>       Prev Tab       </source>
        <translation>    Föregående tabb   </translation>
    </message>
    <message>
        <source>Save Link in Bookmarks</source>
        <translation>Spara länk i bokmärken</translation>
    </message>
    <message>
        <source>Enter URL</source>
        <translation>Skriv in adress</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>      Remove Tab      </source>
        <translation>     Ta bort tabb     </translation>
    </message>
    <message>
        <source>       Zoom Out       </source>
        <translation>       Zooma ut       </translation>
    </message>
    <message>
        <source>       Zoom In        </source>
        <translation>       Zooma in       </translation>
    </message>
</context>
</TS>

==> mythplugins_0.20.2.orig.tar.gz: mythplugins-0.20.2/mythbrowser/i18n/mythbrowser_sv.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>Bookmarks</name>
    <message>
        <source>MythBrowser: Select group or single site to view</source>
        <translation>MythBrowser: Välj grupp eller enstaka sida att se</translation>
    </message>
</context>
<context>
    <name>BookmarksConfig</name>
    <message>
        <source>MythBrowser Bookmarks Settings</source>
        <translation>MythBrowser bokmärkesinställningar</translation>
    </message>
    <message>
        <source>Press the &apos;New Bookmark&apos; button to add a new site/group.
Pressing SPACE/Enter on a selected entry removes it from the listview.</source>
        <translation>Tryck på knappen &apos;Nytt bokmärke&apos; för att lägga till en ny sida/grupp.
Ett tryck på Mellanslag/Enter på en markerad post tar bort den från listvisaren.</translation>
    </message>
    <message>
        <source>Zoom [%]:</source>
        <translation>Zoom [%]:</translation>
    </message>
    <message>
        <source>Browser:</source>
        <translation>Webbläsare:</translation>
    </message>
    <message>
        <source>Hide Scrollbars</source>
        <translation>Dölj rullningslister</translation>
    </message>
    <message>
        <source>Scroll Page</source>
        <translation>Rulla sida</translation>
    </message>
    <message>
        <source>Scroll Speed:</source>
        <translation>Rullningshastighet:</translation>
    </message>
    <message>
        <source>&amp;New Bookmark</source>
        <translation>&amp;Nytt bokmärke</translation>
    </message>
    <message>
        <source>Add a new Website</source>
        <translation>Lägg till en ny webbsida</translation>
    </message>
    <message>
        <source>&amp;Finish</source>
        <translation>&amp;Avsluta</translation>
    </message>
</context>
<context>
    <name>PopupBox</name>
    <message>
        <source>Add New Website</source>
        <translation>Lägg till ny webbsida</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Grupp:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Beskrivning:</translation>
    </message>
    <message>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <source>&amp;Ok</source>
        <translation>&amp;Ok</translation>
    </message>
</context>
<context>
    <name>TabView</name>
    <message>
        <source>MythBrowser Menu</source>
        <translation>MythBrowser-meny</translation>
    </message>
    <message>
        <source>Save Link in Bookmarks</source>
        <translation>Spara länk i bokmärken</translation>
    </message>
    <message>
        <source>Enter URL</source>
        <translation>Skriv in adress</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Bakåt</translation>
    </message>
    <message>
        <source>Next Tab</source>
        <translation>Nästa flik</translation>
    </message>
    <message>
        <source>Prev Tab</source>
        <translation>Föregående flik</translation>
    </message>
    <message>
        <source>Remove Tab</source>
        <translation>Ta bort flik</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>Zooma ut</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>Zooma in</translation>
    </message>
    <message>
        <source>Add New Bookmark</source>
        <translation>Lägg till nytt bokmärke</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Grupp:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Beskrivning:</translation>
    </message>
    <message>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
</context>
</TS>
